<?php

require_once 'PHPUnit/Framework.php';

require_once dirname(__FILE__) . '/../TabbedLinesTree.php';

/**
 * Test class for TabbedLinesTree.
 * Generated by PHPUnit on 2011-03-07 at 13:02:16.
 */
class TabbedLinesTreeTest extends PHPUnit_Framework_TestCase {

    protected $_dom;
    protected $_root;

    protected function _prepare_dom() {
        $this->_dom = new DomDocument('1.0', 'utf-8');
        $this->_dom->formatOutput = true;
        $this->_root = $this->_dom->createElement('items');
        $this->_dom->appendChild($this->_root);
    }

    protected function _add_item($value, $parent = NULL) {
        if ($parent == NULL)
            $parent = $this->_root;

        $item = $this->_dom->createElement("item");
        $item->setAttribute("value", $value);
        $parent->appendChild($item);

        return $item;
    }

    public function testCase1() {
        $text = file_get_contents(dirname(__FILE__) . "/cases/1.txt");

        $this->_prepare_dom();
        $this->_add_item('Line');

        $this->assertEquals(
                $this->_dom->saveXML(),
                TabbedLinesTree::parse($text)->saveXML()
        );
    }

    public function testCase2() {
        $text = file_get_contents(dirname(__FILE__) . "/cases/2.txt");

        $this->_prepare_dom();
        $this->_add_item('Line');

        $this->assertEquals(
                $this->_dom->saveXML(),
                TabbedLinesTree::parse($text)->saveXML()
        );
    }

    public function testCase3() {
        $text = file_get_contents(dirname(__FILE__) . "/cases/3.txt");

        $this->_prepare_dom();
        $this->_add_item('Line 1');
        $this->_add_item('Line 2');

        $this->assertEquals(
                $this->_dom->saveXML(),
                TabbedLinesTree::parse($text)->saveXML()
        );
    }

    public function testCase4() {
        $text = file_get_contents(dirname(__FILE__) . "/cases/4.txt");

        $this->_prepare_dom();
        $line_1 = $this->_add_item('Line 1');
        $this->_add_item('Line 1.1', $line_1);

        $this->assertEquals(
                $this->_dom->saveXML(),
                TabbedLinesTree::parse($text)->saveXML()
        );
    }

    public function testCase5() {
        $text = file_get_contents(dirname(__FILE__) . "/cases/5.txt");

        $this->_prepare_dom();
        $line_1 = $this->_add_item('Line 1');
        $this->_add_item('Line 1.1', $line_1);
        $this->_add_item('Line 1.2', $line_1);

        $this->assertEquals(
                $this->_dom->saveXML(),
                TabbedLinesTree::parse($text)->saveXML()
        );
    }

    public function testCase6() {
        $text = file_get_contents(dirname(__FILE__) . "/cases/6.txt");

        $this->_prepare_dom();
        $line_1 = $this->_add_item('Line 1');
        $this->_add_item('Line 1.1', $line_1);
        $this->_add_item('Line 1.2', $line_1);
        $this->_add_item('Line 2');

        $this->assertEquals(
                $this->_dom->saveXML(),
                TabbedLinesTree::parse($text)->saveXML()
        );
    }

    public function testCase7() {
        $text = file_get_contents(dirname(__FILE__) . "/cases/7.txt");

        $this->_prepare_dom();
        $line_1 = $this->_add_item('Line 1');
        $this->_add_item('Line 1.1', $line_1);
        $this->_add_item('Line 1.2', $line_1);
        $line_2 = $this->_add_item('Line 2');
        $this->_add_item('Line 2.1', $line_2);

        $this->assertEquals(
                $this->_dom->saveXML(),
                TabbedLinesTree::parse($text)->saveXML()
        );
    }

    public function testCase8() {
        $text = file_get_contents(dirname(__FILE__) . "/cases/8.txt");

        $this->_prepare_dom();
        $line_1 = $this->_add_item('Line 1');
        $line_1_1 = $this->_add_item('Line 1.1', $line_1);
        $line_1_1_1 = $this->_add_item('Line 1.1.1', $line_1_1);
        $line_1_2 = $this->_add_item('Line 1.2', $line_1);
        $line_1_2_1 = $this->_add_item('Line 1.2.1', $line_1_2);
        $line_1_2_2 = $this->_add_item('Line 1.2.2', $line_1_2);
        $line_1_2_2_1 = $this->_add_item('Line 1.2.2.1', $line_1_2_2);
        $line_1_2_2_2 = $this->_add_item('Line 1.2.2.2', $line_1_2_2);

        $line_2 = $this->_add_item('Line 2');
        $line_2_1 = $this->_add_item('Line 2.1', $line_2);

        

        $this->assertEquals(
                $this->_dom->saveXML(),
                TabbedLinesTree::parse($text)->saveXML()
        );
    }

    public function testCase9() {
        $text = file_get_contents(dirname(__FILE__) . "/cases/9.txt");

        $this->_prepare_dom();
        $line_1 = $this->_add_item('Строка 1');
        $line_1_1 = $this->_add_item('Строка 1.1', $line_1);
        $line_1_1_1 = $this->_add_item('Строка 1.1.1', $line_1_1);
        $line_1_2 = $this->_add_item('Строка 1.2', $line_1);
        $line_1_2_1 = $this->_add_item('Строка 1.2.1', $line_1_2);
        $line_1_2_2 = $this->_add_item('Строка 1.2.2', $line_1_2);
        $line_1_2_2_1 = $this->_add_item('Строка 1.2.2.1', $line_1_2_2);
        $line_1_2_2_2 = $this->_add_item('Строка 1.2.2.2', $line_1_2_2);

        $line_2 = $this->_add_item('Строка 2');
        $line_2_1 = $this->_add_item('Строка 2.1', $line_2);



        $this->assertEquals(
                $this->_dom->saveXML(),
                TabbedLinesTree::parse($text)->saveXML()
        );
    }
}
?>
